@@ -24,6 +24,7 @@ class Requests(_defaults_.Defaults):
 			send_code,
 			self.ResetPassword(defaults=defaults),
 			self.Activate(defaults=defaults),
+			self.Authenticated(defaults=defaults),
 		])
 
 	# sign up.
@@ -101,9 +102,9 @@ class Requests(_defaults_.Defaults):
 				response = self.rate_limit.verify(ip=utils.get_client_ip(request), mode="daily", limit=1000, reset_minutes=3600*24, increment=True)
 				if not response.success: return self.response(response)
 
-				# check signup rate limit.
-				#response = self.rate_limit.verify(ip=utils.get_client_ip(request), mode="signin", limit=5, reset_minutes=10, increment=True)
-				#if not response.success: return self.response(response)
+				# check signin rate limit.
+				response = self.rate_limit.verify(ip=utils.get_client_ip(request), mode="signin", limit=10, reset_minutes=5, increment=True)
+				if not response.success: return self.response(response)
 
 				# retrieve params.
 				parameters, response = self.parameters.get(request, [
@@ -308,7 +309,7 @@ class Requests(_defaults_.Defaults):
 	# is authenticated.
 	class Authenticated(views.Request):
 		def __init__(self, defaults=None,):
-			views.Request.__init__(self, "requests/authentication/", "activate")
+			views.Request.__init__(self, "requests/authentication/", "authenticated")
 			self.assign(defaults.dict())
 		def request(self, request):
 			try:
@@ -321,7 +322,7 @@ class Requests(_defaults_.Defaults):
 				return self.response("Successfully checked if the user is authenticated.", {
 					"authenticated":request.user.username != None and request.user.is_authenticated == True,
 					"username":request.user.username,
-					"email":request.user.email,
+					#"email":request.user.email,
 				})
 
 			# catch error.
